;+
; PROJECT:
;   RHESSI/INVERSION
;
; NAME:
;  inv_cross_section
;
; PURPOSE:
;
;   Calculates cross-section matrix
;
; CATEGORY:
;   HESSI, Spectra, Inversion
;
; CALLING SEQUENCE:
;
;  inv_cross_section,ee,eps,z,cs,de
;
; CALLS:
;
;  Brm_BremCross.pro (Haug, 97 cross-section /a part of SSW/)
;
;
; INPUTS:
;
;  ee   - array, mid-bin electron energy, keV
;  de   - array, electron energy bin width, keV
; eps   - mid-bin count energy, keV
;   z   - average number of electrons per H atom in solar corona
;
; OPTIONAL INPUTS:
;   none
;
; OUTPUTS:
;
; cs   - cross-section matrix
;
; OPTIONAL OUTPUTS:
;   none
;
; KEYWORDS:
;   none
;
; COMMON BLOCKS:
;   none
;
; SIDE EFFECTS:
;
;
; RESTRICTIONS:
;
;
; MODIFICATION HISTORY:
;   eduard(at)astro.gla.ac.uk, 23 May, 2005
;-

pro inv_cross_section,ee,eps,z,cs,de
; computes all elements of the cross-section

cs=dblarr(N_elements(ee),N_elements(eps))

for i=0,N_elements(eps)-1 do begin
    for j=0,n_elements(ee)-1 do begin
     if eps(i) LT ee(j)*1.0001D0 then begin
     Brm_BremCross,ee(j)*1.0001D0,eps(i), z, cross_section
     ;cross_section=bremss_cross(Ee(j)*1.0001D0,eps(i),Z,/NoElec)
     cs(j,i)=cross_section*(1.e+022)*de(j)/510.98
     ;511 is due to the Haug's subroutine returns in cm2
     IF FINITE(cross_section, /NAN) EQ 1 THEN Print, j,i,cross_section
     end
    end
end

end

