;+
; PROJECT:
;   RHESSI/INVERSION
;
; NAME:
;   inv_make_constraint
;
; PURPOSE:
;   to make contraint matrix
;
; CATEGORY:
;   HESSI, Spectra, Inversion
;
; CALLING SEQUENCE:
;  inv_make_constraint,L,ee,de,fbar0,order
;
; CALLS:
;   none
;
; INPUTS:
;   ee    - array, middle bin energy
;   de    - array, width of energy bins
;   fbar0 - array, forward fit guess
;   order - scalar, oder of regularization
;
; OPTIONAL INPUTS:
;   none
;
; OUTPUTS:
;    L -  constraint matrix
;
; OPTIONAL OUTPUTS:
;   none
;
; KEYWORDS:
;   none
;
; COMMON BLOCKS:
;   none
;
; SIDE EFFECTS:
;  second order regularization works somewhat worse than zero/first
;
;
; RESTRICTIONS:
;
;
; MODIFICATION HISTORY:
;   eduard(at)astro.gla.ac.uk, 23 May, 2005
;
;-


pro inv_make_constraint,L,ee,de,fbar0,order


M=N_ELEMENTS(de)

D2=fltarr(M,M)

for i=0, M-1 do D2(i,i)  =-2.*SQRT(de(i))/sqrt(fbar0(i)/ee(i)^2);/de(i)^1.5
for i=0, M-2 do D2(i,i+1)= 1.*SQRT(de(i))/sqrt(fbar0(i)/ee(i)^2);/de(i)^1.5
for i=1, M-1 do D2(i,i-1)= 1.*SQRT(de(i))/sqrt(fbar0(i)/ee(i)^2);/de(i)^1.5


D1=fltarr(M,M)
for i=0, M-2 do D1(i,i+1)= SQRT(de(i))/sqrt(fbar0(i)/ee(i));/SQRT(de(i))
for i=0, M-1 do D1(i,i)  =-SQRT(de(i))/sqrt(fbar0(i)/ee(i));/SQRT(de(i))


D0=fltarr(M,M)
;For i=0, M-1 do D0(i,i)=1./sqrt(fbar0(i))
For i=0, M-1 do D0(i,i)=SQRT(de(i))/sqrt(fbar0(i))


IF (order NE 0) AND (order NE 1) AND (order NE 2) THEN  BEGIN
order=0
message,'WARNING: order should be 0,1,or 2 only.regularization order set to zero !'
end

IF (order EQ 0) then L=D0
IF (order EQ 1) then L=D1
IF (order EQ 2) then L=D2

end


