;+
; PROJECT:
;   RHESSI/INVERSION
;
; NAME:
;
;   inv_reg_solution,sigmaA,SigmaB,U,W,data,opt,fbar_fit,reg_sol
;
; PURPOSE:
;
;   calculates regulalarised solution
;
; CATEGORY:
;   HESSI, Spectra, Inversion
;
; CALLING SEQUENCE:
;
;  inv_reg_solution,sigmaA,SigmaB,U,W,data,opt,fbar_fit,reg_sol
;
; CALLS:
;   none
;
; INPUTS:
;  SigmaA - vector, generalised singular values
;  SigmaB - vector, generalised singular values
;  U      - matrix, GSVD matrix
;  W      - matrix, GSVD matrix
;  data   - vector, containing count flux
;  opt    - scalar, regularization parameter
;  Fbar_fit-vector, electron flux taken from forward-fit
;
; OPTIONAL INPUTS:
;   none
;
; OUTPUTS:
;   reg_sol -  regularization parameter
;
; OPTIONAL OUTPUTS:
;   none
;
; KEYWORDS:
;   none
;
; COMMON BLOCKS:
;   none
;
; SIDE EFFECTS:
;
;
; RESTRICTIONS:
;
;
; MODIFICATION HISTORY:
;   eduard(at)astro.gla.ac.uk, 16 Sept, 2005
;-


pro inv_reg_solution,sigmaA,SigmaB,U,W,data,opt,fbar_fit,reg_sol
;regularised solution

ar=fltarr(n_elements(data),N_elements(sigmaA))

omega=invert(w)##fbar_fit

for k=0,N_elements(data)-1 do begin
  scal =data##u[k,*]
  for j=0,N_elements(SigmaA)-1 do begin
 ar[k,j]=(sigmaA[k]*scal+opt*omega(k)*SigmaB[k]^2)*w[k,j]/(sigmaA[k]*sigmaA[k]+opt*sigmaB[k]*sigmaB[k])
;arg1[k,j]=(scal*SigmaB[k]/sigmaA[k]+)*sigmaA[k]*SigmaA[k]*w[k,j]/(sigmaA[k]*sigmaA[k]+opt*sigmaB[k]*sigmaB[k])
  end
 end

reg_sol=total(ar,1)

end
