;+
; PROJECT:
;   RHESSI/INVERSION
;
; NAME:
;
;  RESIDUALS
;
; PURPOSE:
;   Calculates, plots to sreen and ps file residuals for
;   regularised solution perform
;
; CATEGORY:
;   HESSI, Spectra, Inversion
;
; CALLING SEQUENCE:
;
;  inv_residuals,count_reg,counts,ecounts,e_c,ps_file_err
;
; CALLS:
;   none
;
; INPUTS:
;
;  count_reg - vector, regularised count flux
;  counts    - vector, count flux
;  ecounts   - vector, 1 sigma uncertanty
;  e_c       - vector, bin averaged energy
;  ps_file_err - string, name of the ps file to save the plot
;
;
; OPTIONAL INPUTS:
;   none
;
; OUTPUTS:
;
;  PS file save to working directory
;
; OPTIONAL OUTPUTS:
;   none
;
; KEYWORDS:
;   none
;
; COMMON BLOCKS:
;   none
;
; SIDE EFFECTS:
;
;
; RESTRICTIONS:
;
;
; MODIFICATION HISTORY:
;   eduard(at)astro.gla.ac.uk, 20- Sept-2005
;
;-


PRO inv_RESIDUALS,count_reg,counts,ecounts,e_c,ps_file_err
;calculates,plots,and saves the residuals

res=(count_reg-counts)/ecounts

res_sum=fltarr(N_elements(e_c))
for k=0,N_elements(e_c)-1 do res_sum(k)=total(res(0:k))/(float(k)+1.)

BinN=findgen(N_elements(e_c))+1.

window,3,xsize=600,ysize=600,title='Normalised and cumulative residuals'
!P.Multi=[0,1,2]

plot,e_c,res,xrange=[min(e_c),max(e_c)],ytitle='Normilised residuals',/xlog,$
xstyle=1,xtitle='Energy, keV',yrange=[-3,3],PSYM=10,ystyle=1
oplot,e_c,e_c/e_c,line=1
oplot,e_c,-e_c/e_c,line=1

plot,e_c,res_sum,xrange=[min(e_c),max(e_c)],ytitle='Cumulative residuals',/xlog,$
xstyle=1,xtitle='Energy, keV',yrange=[-1,1],PSYM=10
oplot,e_c, 1./sqrt(BinN),line=1
oplot,e_c,-1./sqrt(BinN),line=1
oplot,e_c, 3./sqrt(BinN),line=1
oplot,e_c,-3./sqrt(BinN),line=1

!p.multi=0
;***********************************************************************
current_plot=!D.name
Set_plot, 'PS'
Device,filename=ps_file_err, xsize=18,ysize=18,ENCAPSULATED=1
!P.MULTI=[0,1,2]

plot,e_c,res,xrange=[min(e_c),max(e_c)],ytitle='Normilised residuals',/xlog,$
xstyle=1,xtitle='Energy, keV',yrange=[-3,3],PSYM=10,ystyle=1
oplot,e_c,e_c/e_c,line=1
oplot,e_c,-e_c/e_c,line=1

plot,e_c,res_sum,xrange=[min(e_c),max(e_c)],ytitle='Cumulative residuals',/xlog,$
xstyle=1,xtitle='Energy, keV',yrange=[-1,1],PSYM=10
oplot,e_c, 1./sqrt(BinN),line=1
oplot,e_c,-1./sqrt(BinN),line=1
oplot,e_c, 3./sqrt(BinN),line=1
oplot,e_c,-3./sqrt(BinN),line=1

!P.MULTI=0
DEVICE, /CLOSE
SET_PLOT, current_plot
;***********************************************************************


CHI2=total(res*res)/n_elements(res)
Print,'CHI2 = ', CHI2

end


