;+
; PROJECT:
;   RHESSI/INVERSION
;
; NAME:
;
;  inv_save_photons
;
; PURPOSE:
;
;   The routines saves and plots main results of the regularization
;
; CATEGORY:
;   HESSI, Spectra, Inversion
;
; CALLING SEQUENCE:
;
;  inv_save_photons,ee,e_c,reg_sol,reg_sol_err,FWHM,ph_thin,counts,ecounts,ph_reg,sol_file,sol_ps
;
; CALLS:
;   none
;
; INPUTS:
;
;   ee   - vector, electron middle bin energy
;   e_c  - vector, count middle bin energy
; reg_sol- vector, regularised solution
; reg_sol_err - vector, 1 sigma errors for regularised solution
;  FWHM       - vector, energy resolution of the regularised solution
;  f_thin     - vector, forward-fit
;  counts     - vector, input count flux
;  ecounts    - vector, 1 sigma uncertanties for count flux
;  ph_reg     - vector, regularised count flux
; sol_file    - string, output data filename
; sol_ps      - string, PS plot filename
;
;
; OPTIONAL INPUTS:
;
; OUTPUTS:
;
;  IDL save file with the results
;  PS file with the results
;
; KEYWORDS:
;   none
;
; COMMON BLOCKS:
;   none
;
; SIDE EFFECTS:
;
;
; RESTRICTIONS:
;
; MODIFICATION HISTORY:
;   eduard(at)astro.gla.ac.uk, 23 May, 2005
;
;-


pro inv_save_photons,ee,e_c,reg_sol,reg_sol_err,FWHM,ph_model,counts,ecounts,ph_reg,sol_file,sol_ps
; to plot and save the data

;***********************************************************************
window,2, xsize=600,ysize=600,title='Regularized solution and regularized count flux'
!P.Multi=[0,1,2]
ploterror,e_c,reg_sol,reg_sol_err,NSKIP=2,xtitle='Energy, kev',$
ytitle='<I(!4e!3)>, [photons sec!E-1!N keV !E-1!N cm!E-2!N]',title='Photon Flux: regularised & forward fit'$
,xstyle=1,ystyle=1,yrange=[min(ph_model)/5.,max(ph_model)*5.],xrange=[min(e_c),max(e_c)],/xlog,/ylog
oplot,ee,ph_model,line=1

ploterror,e_c,counts,ecounts, ytitle='counts sec!E-1!N keV !E-1!N cm!E-2!N',$
xtitle='Energy, keV',xstyle=1,ystyle=1,/xlog,/ylog,title='Count Flux: regularised & forward fit',$
yrange=[min(counts)/5.,max(counts)*5.],xrange=[min(e_c),max(e_c)],line=1
oplot,e_c,ph_reg,line=0

!P.multi=0

;***********************************************************************

current_plot=!D.name
Set_plot, 'PS'
Device,filename=sol_ps, xsize=18,ysize=18,ENCAPSULATED=1
!P.MULTI=[0,1,2]

ploterror,e_c,reg_sol,reg_sol_err,NSKIP=2,xtitle='Energy, kev',$
ytitle='<nVF>, [10!E50!N elec sec!E-1!N keV !E-1!N cm!E-2!N]',title='Electron Flux: regularised & forward fit'$
,xstyle=1,ystyle=1,yrange=[min(ph_model)/5.,max(ph_model)*5.],xrange=[min(e_c),max(e_c)],/xlog,/ylog
oplot,e_c,ph_model,line=1

ploterror,e_c,counts,ecounts, ytitle='counts sec!E-1!N keV !E-1!N cm!E-2!N',$
xtitle='Energy, keV',xstyle=1,ystyle=1,/xlog,/ylog,title='Count Flux: regularised & forward fit',$
yrange=[min(counts)/5.,max(counts)*5.],xrange=[min(e_c),max(e_c)],line=1
oplot,e_c,ph_reg,line=0

!P.MULTI=0
DEVICE, /CLOSE
SET_PLOT, current_plot
;***********************************************************************

p={ee:ee,e_c:e_c,reg_sol:reg_sol,reg_sol_err:reg_sol_err,FWHM:FWHM}
SAVE,FILENAME = sol_file,p
;saves results for the use outside SPEX

end
